==> haskell-wai-handler-launch-3.0.3.1-616-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-9kUREI3ApMlDjZh35X7eeT
key:                  wai-handler-launch-3.0.3.1-9kUREI3ApMlDjZh35X7eeT
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  e29779c785fa5917b8e86bb16e8eb7bd
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-9kUREI3ApMlDjZh35X7eeT
depends:
    async-2.2.5-BrTWnMUC2zMDZ2E35FeCoi base-4.16.4.0
    bytestring-0.11.4.0 http-types-0.12.4-9vzTx0RF9aB1UjOQOhUDKg
    process-1.6.16.0 streaming-commons-0.2.2.6-Bycd6JtyIG3D94pKvbZUe7
    transformers-0.5.6.2 wai-3.2.4-Hx8a5HTOQSLLESHKvKusBL
    warp-3.3.30-8oc52pAaRed3eHrzEoTP2k

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.3.1-617-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-IWE2hvGzcsExbGI8trzuG
key:                  wai-handler-launch-3.0.3.1-IWE2hvGzcsExbGI8trzuG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  d978e87d6baf0eac655f18bf287de66b
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-IWE2hvGzcsExbGI8trzuG
depends:
    async-2.2.5-BrTWnMUC2zMDZ2E35FeCoi base-4.16.4.0
    bytestring-0.11.4.0 http-types-0.12.4-9vzTx0RF9aB1UjOQOhUDKg
    process-1.6.16.0 streaming-commons-0.2.2.6-Bycd6JtyIG3D94pKvbZUe7
    transformers-0.5.6.2 wai-3.2.4-Hx8a5HTOQSLLESHKvKusBL
    warp-3.3.30-6oWDnWHSzEUAyefPYwYham

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
